/* Skrift CMS — Public Site Theme
   ======================================== */

/* ========================================
   Navigation (Sticky Glassmorphic)
   ======================================== */

.sk-nav {
    position: sticky;
    top: 0;
    z-index: 100;
    background: rgba(7, 11, 20, 0.75);
    backdrop-filter: blur(20px);
    -webkit-backdrop-filter: blur(20px);
    border-bottom: 1px solid var(--sk-color-border);
    transition: background 0.3s;
}

.sk-nav-inner {
    max-width: var(--sk-content-width, 1200px);
    margin: 0 auto;
    padding: 0 2rem;
    height: 64px;
    display: flex;
    align-items: center;
    justify-content: space-between;
}

.sk-nav-logo {
    font-family: var(--sk-font-display);
    font-size: 1.35rem;
    font-weight: 700;
    background: var(--sk-gradient-brand);
    -webkit-background-clip: text;
    -webkit-text-fill-color: transparent;
    background-clip: text;
    letter-spacing: -0.02em;
    text-decoration: none;
}

.sk-nav-links {
    display: flex;
    gap: 0.25rem;
    align-items: center;
}

.sk-nav-link {
    font-size: 0.85rem;
    font-weight: 400;
    color: var(--sk-color-text-secondary);
    text-decoration: none;
    padding: 0.45rem 0.85rem;
    border-radius: var(--sk-radius-md);
    transition: all 0.2s;
}

.sk-nav-link:hover {
    color: var(--sk-color-text);
    background: var(--sk-color-surface);
}

.sk-nav-link.active {
    color: var(--sk-color-text);
    background: var(--sk-color-surface);
}

.sk-nav-cta {
    font-size: 0.8rem;
    font-weight: 500;
    color: var(--sk-color-bg);
    background: var(--sk-gradient-accent);
    padding: 0.5rem 1.1rem;
    border-radius: var(--sk-radius-md);
    transition: all 0.25s;
    text-decoration: none;
    box-shadow: none;
    border: none;
    line-height: 1;
}

.sk-nav-cta:hover {
    opacity: 0.9;
    transform: translateY(-1px);
    box-shadow: 0 4px 20px rgba(52, 211, 153, 0.3);
    color: var(--sk-color-bg);
}

/* ========================================
   Page Content Wrapper
   ======================================== */

.sk-page-content {
    position: relative;
    z-index: 1;
    display: flex;
    flex-direction: column;
    min-height: 100vh;
}

/* ========================================
   Content Container
   ======================================== */

.sk-content {
    max-width: var(--sk-content-width, 1200px);
    width: 100%;
    margin: 0 auto;
    padding: 2.5rem 2rem var(--sk-space-2xl);
    flex: 1;
}

/* ========================================
   Hero
   ======================================== */

.sk-hero {
    max-width: var(--sk-content-width, 1200px);
    margin: 0 auto;
    padding: 5rem 2rem 3rem;
    text-align: center;
    position: relative;
}

.sk-hero-badge {
    display: inline-flex;
    align-items: center;
    gap: 0.5rem;
    font-size: 0.75rem;
    font-weight: 500;
    color: var(--sk-color-accent);
    background: var(--sk-color-accent-soft);
    border: 1px solid rgba(52, 211, 153, 0.15);
    padding: 0.4rem 1rem;
    border-radius: var(--sk-radius-pill);
    margin-bottom: 1.5rem;
}

.sk-hero h1 {
    font-family: var(--sk-font-display);
    font-size: clamp(2.5rem, 5vw, 3.8rem);
    font-weight: 700;
    line-height: 1.1;
    letter-spacing: -0.03em;
    margin-bottom: 1rem;
}

.sk-hero p {
    font-size: 1.05rem;
    color: var(--sk-color-text-secondary);
    max-width: 560px;
    margin: 0 auto 2rem;
}

.sk-hero .sk-badge {
    display: inline-block;
    font-size: 1rem;
    padding: 0.25rem 0.75rem;
    border-radius: 0.375rem;
    background: var(--sk-color-accent-soft);
    color: var(--sk-color-accent);
    font-weight: 600;
    text-transform: uppercase;
    letter-spacing: 0.06em;
    margin-bottom: 1rem;
    align-self: flex-start;
}

.sk-hero .sk-meta {
    font-size: 1rem;
    color: var(--sk-color-muted);
}

.sk-hero .sk-meta strong {
    color: var(--sk-color-text);
}

/* ========================================
   Section Labels
   ======================================== */

.sk-section-label {
    font-family: var(--sk-font-display);
    font-size: 1rem;
    font-weight: 600;
    text-transform: uppercase;
    letter-spacing: 0.1em;
    color: var(--sk-color-muted);
    margin-bottom: 1.25rem;
}

/* ========================================
   Filter Pills
   ======================================== */

.sk-filter-pills {
    display: flex;
    gap: 0.4rem;
    flex-wrap: wrap;
}

.sk-filter-pill {
    font-family: var(--sk-font-body);
    font-size: 0.78rem;
    font-weight: 400;
    color: var(--sk-color-text-secondary);
    background: transparent;
    border: 1px solid var(--sk-color-border);
    padding: 0.4rem 1rem;
    border-radius: var(--sk-radius-pill);
    cursor: pointer;
    transition: all 0.25s;
}

.sk-filter-pill:hover {
    border-color: var(--sk-color-border-hover);
    color: var(--sk-color-text);
    background: var(--sk-color-surface);
}

.sk-filter-pill.active {
    color: var(--sk-color-bg);
    background: var(--sk-gradient-accent);
    border-color: transparent;
    font-weight: 500;
}

/* ========================================
   Card Grid
   ======================================== */

.sk-card-grid {
    display: grid;
    grid-template-columns: repeat(2, 1fr);
    gap: 1.5rem;
}

@media (max-width: 900px) {
    .sk-card-grid {
        grid-template-columns: 1fr;
    }
}

/* ========================================
   Post Cards
   ======================================== */

.sk-post-card {
    position: relative;
    background: var(--sk-color-surface);
    border: 1px solid var(--sk-color-border);
    border-radius: var(--sk-radius-xl);
    overflow: hidden;
    transition: all 0.35s cubic-bezier(0.25, 0.46, 0.45, 0.94);
}

.sk-post-card::before {
    content: '';
    position: absolute;
    inset: -1px;
    border-radius: calc(var(--sk-radius-xl) + 1px);
    background: var(--sk-gradient-brand);
    opacity: 0;
    transition: opacity 0.35s;
    z-index: -1;
}

.sk-post-card:hover::before {
    opacity: 1;
}

.sk-post-card:hover {
    border-color: transparent;
    transform: translateY(-4px);
    box-shadow: 0 12px 40px rgba(52, 211, 153, 0.08),
                0 4px 16px rgba(139, 92, 246, 0.06);
}

.sk-post-card-inner {
    background: var(--sk-color-bg);
    margin: 1px;
    border-radius: calc(var(--sk-radius-xl) - 1px);
    overflow: hidden;
    height: calc(100% - 2px);
    display: flex;
    flex-direction: column;
}

.sk-post-card-img {
    height: 10rem;
    display: flex;
    align-items: center;
    justify-content: center;
    color: rgba(255, 255, 255, 0.2);
    font-family: var(--sk-font-display);
    font-size: 2rem;
    font-weight: 600;
    background: linear-gradient(135deg, var(--sk-color-accent), var(--sk-violet));
    overflow: hidden;
    aspect-ratio: 16 / 9;
}

.sk-post-card-body {
    padding: 1.25rem 1.5rem 1.5rem;
    flex: 1;
    display: flex;
    flex-direction: column;
}

.sk-post-card .sk-badge {
    display: inline-block;
    font-size: 1rem;
    padding: 0.1875rem 0.5625rem;
    border-radius: 0.3125rem;
    background: var(--sk-color-accent-soft);
    color: var(--sk-color-accent);
    font-weight: 600;
    text-transform: uppercase;
    letter-spacing: 0.04em;
    margin-bottom: 0.625rem;
}

.sk-post-card h3 {
    font-family: var(--sk-font-display);
    font-size: 1.15rem;
    font-weight: 600;
    line-height: 1.35;
    letter-spacing: -0.01em;
    margin-bottom: 0.5rem;
}

.sk-post-card p {
    font-size: 0.85rem;
    line-height: var(--sk-line-height);
    color: var(--sk-color-text-secondary);
    margin-bottom: 0.75rem;
    flex: 1;
}

.sk-post-card .sk-meta {
    font-size: 1rem;
    color: var(--sk-color-muted);
}

/* ========================================
   Pagination
   ======================================== */

.sk-pagination {
    display: flex;
    align-items: center;
    justify-content: center;
    gap: 0.35rem;
    padding: 2rem 0;
}

.sk-page-btn {
    font-family: var(--sk-font-body);
    font-size: 0.82rem;
    font-weight: 500;
    width: 38px;
    height: 38px;
    display: flex;
    align-items: center;
    justify-content: center;
    border-radius: 10px;
    border: 1px solid var(--sk-color-border);
    background: transparent;
    color: var(--sk-color-text-secondary);
    cursor: pointer;
    transition: all 0.2s;
    box-shadow: none;
    padding: 0;
}

.sk-page-btn:hover {
    border-color: var(--sk-color-border-hover);
    color: var(--sk-color-text);
    background: var(--sk-color-surface);
    box-shadow: none;
    opacity: 1;
}

.sk-page-btn.active {
    background: var(--sk-gradient-accent);
    color: var(--sk-color-bg);
    border-color: transparent;
    font-weight: 600;
}

/* ========================================
   Footer
   ======================================== */

.sk-footer {
    border-top: 1px solid var(--sk-color-border);
    padding: 1.5rem 2rem;
    color: var(--sk-color-text-secondary);
}

.sk-footer-inner {
    max-width: var(--sk-content-width, 1200px);
    margin: 0 auto;
    display: grid;
    grid-template-columns: 1.5fr 1fr 1fr 1fr;
    gap: 3rem;
}

.sk-footer-brand {
    font-family: var(--sk-font-display);
    font-size: 1.2rem;
    font-weight: 700;
    color: var(--sk-color-text);
    margin-bottom: 0.75rem;
    display: inline-block;
}

.sk-footer-brand p,
.sk-footer-desc {
    font-size: 0.82rem;
    color: var(--sk-color-text-secondary);
    line-height: 1.6;
    max-width: 280px;
}

.sk-footer-col h4 {
    font-family: var(--sk-font-display);
    font-size: 0.82rem;
    font-weight: 600;
    margin-bottom: 0.85rem;
    color: var(--sk-color-text);
}

.sk-footer-col a {
    display: block;
    font-size: 0.8rem;
    color: var(--sk-color-text-secondary);
    text-decoration: none;
    padding: 0.25rem 0;
    transition: color 0.2s;
}

.sk-footer-col a:hover {
    color: var(--sk-color-accent);
}

.sk-footer-bottom {
    max-width: var(--sk-content-width, 1200px);
    margin: 0 auto;
    display: flex;
    align-items: center;
    justify-content: space-between;
    font-size: 0.75rem;
    color: var(--sk-color-text-secondary);
}

/* ========================================
   Article / Page Content
   ======================================== */

article {
    margin-bottom: var(--sk-space-lg);
}

article:last-child {
    margin-bottom: 0;
}

article header {
    padding: 0;
    margin-bottom: var(--sk-space-md);
}

article footer {
    padding: 0;
    margin-top: var(--sk-space-lg);
}

/* ========================================
   Responsive
   ======================================== */

@media (max-width: 900px) {
    .sk-hero {
        padding: 3rem 1.5rem 2rem;
    }

    .sk-footer-inner {
        grid-template-columns: 1fr 1fr;
        gap: 2rem;
    }
}

@media (max-width: 600px) {
    .sk-nav-inner {
        padding: 0 1rem;
    }

    .sk-nav-link.hide-mobile {
        display: none;
    }

    .sk-hero {
        padding: 2rem 1rem 1.5rem;
    }

    .sk-hero h1 {
        font-size: 1.75rem;
    }

    .sk-content {
        padding: 0 1rem var(--sk-space-2xl);
    }

    .sk-footer-inner {
        grid-template-columns: 1fr;
    }
}

/* ========================================
   Light Theme Overrides
   ======================================== */

@media (prefers-color-scheme: light) {
    .sk-nav {
        background: rgba(248, 250, 252, 0.85);
    }

    .sk-nav-cta {
        color: #fff;
    }

    .sk-post-card-inner {
        background: var(--sk-color-surface);
    }
}
